@@ -7,11 +7,23 @@ import sys
 import warnings
 from typing import Any, Dict, List, Optional
 
-from pystac import STACTypeError
+from pystac import STACError, STACTypeError
 
 from .client import Client
 from .conformance import ConformanceClasses
-from .item_search import OPS
+from .item_search import (
+    OPS,
+    BBoxLike,
+    CollectionsLike,
+    DatetimeLike,
+    FieldsLike,
+    FilterLangLike,
+    FilterLike,
+    IDsLike,
+    IntersectsLike,
+    QueryLike,
+    SortbyLike,
+)
 from .version import __version__
 from .warnings import (
     DoesNotConformTo,
@@ -26,34 +38,54 @@ logger = logging.getLogger(__name__)
 
 def search(
     client: Client,
-    method: str = "GET",
     matched: bool = False,
     save: Optional[str] = None,
-    **kwargs: Dict[str, Any],
+    *,
+    method: str = "GET",
+    max_items: Optional[int] = None,
+    limit: Optional[int] = None,
+    ids: Optional[IDsLike] = None,
+    collections: Optional[CollectionsLike] = None,
+    bbox: Optional[BBoxLike] = None,
+    intersects: Optional[IntersectsLike] = None,
+    datetime: Optional[DatetimeLike] = None,
+    query: Optional[QueryLike] = None,
+    filter: Optional[FilterLike] = None,
+    filter_lang: Optional[FilterLangLike] = None,
+    sortby: Optional[SortbyLike] = None,
+    fields: Optional[FieldsLike] = None,
 ) -> int:
     """Main function for performing a search"""
 
-    try:
-        # https://github.com/python/mypy/issues/4441
-        # the type: ignore is to silence the mypy error
-        # error: Argument 2 to "search" of "Client" has incompatible
-        # type "**Dict[str, Dict[str, Any]]"; expected "Optional[int]"  [arg-type]
-        result = client.search(method=method, **kwargs)  # type: ignore[arg-type]
+    result = client.search(
+        method=method,
+        max_items=max_items,
+        limit=limit,
+        ids=ids,
+        collections=collections,
+        bbox=bbox,
+        intersects=intersects,
+        datetime=datetime,
+        query=query,
+        filter=filter,
+        filter_lang=filter_lang,
+        sortby=sortby,
+        fields=fields,
+    )
 
-        if matched:
-            print(f"{result.matched()} items matched")
+    if matched:
+        if (nmatched := result.matched()) is not None:
+            print(f"{nmatched} items matched")
         else:
-            feature_collection = result.item_collection_as_dict()
-            if save:
-                with open(save, "w") as f:
-                    f.write(json.dumps(feature_collection))
-            else:
-                print(json.dumps(feature_collection))
-        return 0
-
-    except Exception as e:
-        print(f"ERROR: {e}")
-        return 1
+            raise KeyError("'matched' is not supported for this catalog")
+    else:
+        feature_collection = result.item_collection_as_dict()
+        if save:
+            with open(save, "w") as f:
+                f.write(json.dumps(feature_collection))
+        else:
+            print(json.dumps(feature_collection))
+    return 0
 
 
 def collections(client: Client, save: Optional[str] = None) -> int:
@@ -65,17 +97,12 @@ def collections(client: Client, save: Optional[str] = None) -> int:
                 f.write(json.dumps(collections_dicts))
         else:
             print(json.dumps(collections_dicts))
-        return 0
     except STACTypeError as e:
-        print(f"ERROR: {e}")
-        print(
+        raise STACError(
             f"The client at {client.self_href} is OK, but one or more of the "
             "collections is invalid."
-        )
-        return 1
-    except Exception as e:
-        print(f"ERROR: {e}")
-        return 1
+        ) from e
+    return 0
 
 
 def add_warnings_behavior(parser: argparse.ArgumentParser) -> None:
@@ -109,7 +136,7 @@ def set_warnings(error: Optional[List[str]], ignore: Optional[List[str]]) -> Non
     if ignore is not None and len(ignore) == 0:
         warnings.filterwarnings("ignore", category=PystacClientWarning)
     if error is not None and len(error) == 0:
-        warnings.filterwarnings("ignore", category=PystacClientWarning)
+        warnings.filterwarnings("error", category=PystacClientWarning)
 
     # Then set filters on any specific classes
     category_options = {
@@ -227,12 +254,6 @@ def parse_args(args: List[str]) -> Dict[str, Any]:
         nargs="*",
         help=f"Query properties of form KEY=VALUE ({','.join(OPS)} supported)",
     )
-    search_group.add_argument(
-        "-q",
-        nargs="*",
-        help="DEPRECATED. Use --query instead. Query properties of form "
-        "KEY=VALUE (<, >, <=, >=, = supported)",
-    )
     search_group.add_argument(
         "--filter",
         help="Filter on queryables using language specified in filter-lang parameter",
@@ -279,6 +300,10 @@ def parse_args(args: List[str]) -> Dict[str, Any]:
                 if data["type"] == "Feature":
                     parsed_args["intersects"] = data["geometry"]
                 elif data["type"] == "FeatureCollection":
+                    logger.warning(
+                        "When the input to intersects is a FeatureCollection, "
+                        "only the first feature geometry is used."
+                    )
                     parsed_args["intersects"] = data["features"][0]["geometry"]
                 else:
                     parsed_args["intersects"] = data
@@ -299,14 +324,6 @@ def parse_args(args: List[str]) -> Dict[str, Any]:
         if "json" in parsed_args["filter_lang"]:
             parsed_args["filter"] = json.loads(parsed_args["filter"])
 
-    if "q" in parsed_args:
-        logger.warning("Argument -q is deprecated, use --query instead")
-        if "query" not in parsed_args:
-            parsed_args["query"] = parsed_args["q"]
-        else:
-            logger.error("Both -q and --query arguments specified, ignoring -q")
-        del parsed_args["q"]
-
     return parsed_args
 
 
@@ -337,20 +354,18 @@ def cli() -> int:
             args.pop("add_conforms_to", None),
         )
 
+        if cmd == "search":
+            return search(client, **args)
+        elif cmd == "collections":
+            return collections(client, **args)
+        else:
+            logger.error(
+                f"Command '{cmd}' is not a valid command. "
+                "must be 'search' or 'collections'",
+            )
+            return 1
     except Exception as e:
-        print(f"ERROR: {e}", file=sys.stderr)
-        return 1
-
-    if cmd == "search":
-        return search(client, **args)
-    elif cmd == "collections":
-        return collections(client, **args)
-    else:
-        print(
-            f"Command '{cmd}' is not a valid command. "
-            "must be 'search' or 'collections'",
-            file=sys.stderr,
-        )
+        logger.error(e, exc_info=True)
         return 1
 
 
