@@ -25,7 +25,6 @@ from pystac_client.conformance import ConformanceClasses
 from pystac_client.errors import ClientTypeError
 from pystac_client.exceptions import APIError
 from pystac_client.item_search import (
-    DEFAULT_LIMIT_AND_MAX_ITEMS,
     BBoxLike,
     CollectionsLike,
     DatetimeLike,
@@ -439,19 +438,27 @@ class Client(pystac.Catalog, QueryablesMixin):
                 call_modifier(self.modifier, collection)
                 yield collection
 
-    def get_items(self) -> Iterator["Item_Type"]:
+    def get_items(
+        self, *ids: str, recursive: Optional[bool] = None
+    ) -> Iterator["Item_Type"]:
         """Return all items of this catalog.
 
+        Args:
+            ids: Zero or more item ids to find.
+            recursive: unused in pystac-client, but needed for falling back to pystac
+
         Return:
-            Iterator[Item]:: Iterator of items whose parent is this
+            Iterator[Item]: Iterator of items whose parent is this
                 catalog.
         """
         if self.conforms_to(ConformanceClasses.ITEM_SEARCH):
-            search = self.search()
+            search = self.search(ids=ids)
             yield from search.items()
         else:
             self._warn_about_fallback("ITEM_SEARCH")
-            for item in super().get_items():
+            for item in super().get_items(
+                *ids, recursive=recursive is None or recursive
+            ):
                 call_modifier(self.modifier, item)
                 yield item
 
@@ -460,7 +467,7 @@ class Client(pystac.Catalog, QueryablesMixin):
         any subcatalogs recursively, or use the /search endpoint if supported
 
         Returns:
-            Iterator[Item]:: All items that belong to this catalog, and all
+            Iterator[Item]: All items that belong to this catalog, and all
                 catalogs or collections connected to this catalog through
                 child links.
         """
@@ -471,7 +478,7 @@ class Client(pystac.Catalog, QueryablesMixin):
         *,
         method: Optional[str] = "POST",
         max_items: Optional[int] = None,
-        limit: Optional[int] = DEFAULT_LIMIT_AND_MAX_ITEMS,
+        limit: Optional[int] = None,
         ids: Optional[IDsLike] = None,
         collections: Optional[CollectionsLike] = None,
         bbox: Optional[BBoxLike] = None,
@@ -586,7 +593,7 @@ class Client(pystac.Catalog, QueryablesMixin):
 
         if not self.conforms_to(ConformanceClasses.ITEM_SEARCH):
             raise DoesNotConformTo(
-                "ITEM_SEARCH", "There is not fallback option available for search."
+                "ITEM_SEARCH", "There is no fallback option available for search."
             )
 
         return ItemSearch(
