@@ -91,10 +91,14 @@ OP_MAP = {
 
 OPS = list(OP_MAP.keys())
 
-# Previously named DEFAULT_LIMIT_AND_MAX_ITEMS
-# aliased for backwards compat
-# https://github.com/stac-utils/pystac-client/pull/273
-DEFAUL_LIMIT = DEFAULT_LIMIT_AND_MAX_ITEMS = 100
+
+def __getattr__(name: str) -> Any:
+    if name in ("DEFAUL_LIMIT", "DEFAULT_LIMIT_AND_MAX_ITEMS"):
+        warnings.warn(
+            f"{name} is deprecated and will be removed in v0.8", DeprecationWarning
+        )
+        return 100
+    raise AttributeError(f"module {__name__} has no attribute {name}")
 
 
 # from https://gist.github.com/angstwad/bf22d1822c38a92ec0a9#gistcomment-2622319
@@ -172,8 +176,7 @@ class ItemSearch:
             *per page* of results. Defaults to 100.
         ids: List of one or more Item ids to filter on.
         collections: List of one or more Collection IDs or :class:`pystac.Collection`
-            instances. Only Items in one
-            of the provided Collections will be searched
+            instances.
         bbox: A list, tuple, or iterator representing a bounding box of 2D
             or 3D coordinates. Results will be filtered
             to only those intersecting the bounding box.
@@ -258,7 +261,7 @@ class ItemSearch:
         max_items: Optional[int] = None,
         stac_io: Optional[StacApiIO] = None,
         client: Optional["_client.Client"] = None,
-        limit: Optional[int] = DEFAULT_LIMIT_AND_MAX_ITEMS,
+        limit: Optional[int] = None,
         ids: Optional[IDsLike] = None,
         collections: Optional[CollectionsLike] = None,
         bbox: Optional[BBoxLike] = None,
@@ -550,13 +553,18 @@ class ItemSearch:
 
     @staticmethod
     def _format_ids(value: Optional[IDsLike]) -> Optional[IDs]:
-        if value is None:
+        if value is None or isinstance(value, (tuple, list)) and not value:
+            # We can't just check for truthiness here because of the Iterator[str] case
             return None
-
-        if isinstance(value, str):
-            return tuple(value.split(","))
-
-        return tuple(value)
+        elif isinstance(value, str):
+            # We could check for str in the first branch, but then we'd be checking
+            # for str twice #microoptimizations
+            if value:
+                return tuple(value.split(","))
+            else:
+                return None
+        else:
+            return tuple(value)
 
     def _format_sortby(self, value: Optional[SortbyLike]) -> Optional[Sortby]:
         if value is None:
@@ -663,7 +671,7 @@ class ItemSearch:
         resp = self._stac_io.read_json(self.url, method=self.method, parameters=params)
         found = None
         if "context" in resp:
-            found = resp["context"]["matched"]
+            found = resp["context"].get("matched", None)
         elif "numberMatched" in resp:
             found = resp["numberMatched"]
         if found is None:
