@@ -26,7 +26,7 @@ from pystac.serialization import (
 from pystac.stac_io import DefaultStacIO
 from requests import Request, Session
 from requests.adapters import HTTPAdapter
-from typing_extensions import TypeAlias
+from urllib3 import Retry
 
 import pystac_client
 
@@ -39,7 +39,7 @@ if TYPE_CHECKING:
 logger = logging.getLogger(__name__)
 
 
-Timeout: TypeAlias = Union[float, Tuple[float, float], Tuple[float, None]]
+Timeout = Union[float, Tuple[float, float], Tuple[float, None]]
 
 
 class StacApiIO(DefaultStacIO):
@@ -50,7 +50,7 @@ class StacApiIO(DefaultStacIO):
         parameters: Optional[Dict[str, Any]] = None,
         request_modifier: Optional[Callable[[Request], Union[Request, None]]] = None,
         timeout: Optional[Timeout] = None,
-        max_retries: Optional[int] = 5,
+        max_retries: Optional[Union[int, Retry]] = 5,
     ):
         """Initialize class for API IO
 
@@ -268,7 +268,6 @@ class StacApiIO(DefaultStacIO):
             return result
 
         if info.object_type == pystac.STACObjectType.COLLECTION:
-            assert isinstance(root, pystac_client.client.Client)
             return pystac_client.collection_client.CollectionClient.from_dict(
                 d, href=str(href), root=root, migrate=False, preserve_dict=preserve_dict
             )
