@@ -405,8 +405,9 @@ class TestAPI:
         # Mock the collection
         requests_mock.get(pc_collection_href, status_code=200, json=pc_collection_dict)
 
-        with pytest.warns(DoesNotConformTo, match="COLLECTIONS, FEATURES"):
-            _ = next(api.get_collections())
+        with pytest.warns(FallbackToPystac):
+            with pytest.warns(DoesNotConformTo, match="COLLECTIONS, FEATURES"):
+                _ = next(api.get_collections())
 
         history = requests_mock.request_history
         assert len(history) == 2
@@ -682,3 +683,32 @@ class TestConformsTo:
 
         with pytest.warns(MissingLink, match="rel='data'"):
             next(client.get_collections())
+
+
+@pytest.mark.vcr
+def test_collections_are_clients() -> None:
+    # https://github.com/stac-utils/pystac-client/issues/548
+    catalog = Client.open(
+        "https://planetarycomputer.microsoft.com/api/stac/v1/",
+    )
+    item = catalog.get_collection("cil-gdpcir-cc-by").get_item(
+        "cil-gdpcir-NUIST-NESM3-ssp585-r1i1p1f1-day"
+    )
+    assert item
+    item.get_collection()
+
+
+@pytest.mark.vcr
+def test_get_items_without_ids() -> None:
+    client = Client.open(
+        "https://planetarycomputer.microsoft.com/api/stac/v1/",
+    )
+    next(client.get_items())
+
+
+@pytest.mark.vcr
+def test_non_recursion_on_fallback() -> None:
+    path = "https://raw.githubusercontent.com/stac-utils/pystac/v1.9.0/docs/example-catalog/catalog.json"
+    catalog = Client.from_file(path)
+    with pytest.warns(FallbackToPystac):
+        [i for i in catalog.get_items()]
